==> foundation-ui-components-1.8.1.tgz: package/src/common/autocomplete/mock/MockData.ts <==
/* eslint-disable max-len */
import { OptionsProps } from '../types';

export const AutocompleteMockList: OptionsProps[] = [
    {
        id: '1',
        value: 'GS Facial Gels 2pk Subscription',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990168/_jcr_content/fullImage.img.160.160.png.64.64.png',
    },
    {
        id: '2',
        value: 'GS Facial',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550014/_jcr_content/fullImage.img.160.160.png.64.64.png',
    },
    {
        id: '3',
        value: 'GS Facial Spa',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/10/12/01101251/_jcr_content/fullImage.img.160.160.png.64.64.png',
    },
    {
        id: '4',
        value: 'Nu Skin® Facial Spa',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550013/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000',
    },
    {
        id: '5',
        value: 'AP 24® Whitening Fluoride Toothpaste',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990100/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000',
    },
    {
        id: '6',
        value: 'PowerMask + LumiSpa Normal Subscription',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/00/16/01001647/jcr:content/fullImage.img.160.160.png/1611763135883-cache.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000',
    },

    {
        id: '7',
        value: 'Rejuvenating Cream',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990168/_jcr_content/fullImage.img.160.160.png.64.64.png',
    },
    {
        id: '8',
        value: 'Epoch® Firewalker® Foot Cream',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550014/_jcr_content/fullImage.img.160.160.png.64.64.png',
    },
    {
        id: '9',
        value: 'Tri-Phasic White® Night Cream',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/10/12/01101251/_jcr_content/fullImage.img.160.160.png.64.64.png',
    },
    {
        id: '10',
        value: 'ThirstFix Hydrating Gel Cream (Sample Size)',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550013/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000',
    },
    {
        id: '11',
        value: 'Epoch® Baby Hair',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990100/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000',
    },
    {
        id: '12',
        value: '180° Face Wash',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/00/16/01001647/jcr:content/fullImage.img.160.160.png/1611763135883-cache.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000',
    },
];

==> foundation-ui-components-1.30.1.tgz: package/src/common/autocomplete/mock/MockData.ts <==
import { OptionsProps } from '../types';

export const AutocompleteMockList: OptionsProps[] = [
    {
        id: '1',
        value: 'GS Facial Gels 2pk Subscription',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990168/_jcr_content/fullImage.img.160.160.png.64.64.png'
    },
    {
        id: '2',
        value: 'GS Facial',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550014/_jcr_content/fullImage.img.160.160.png.64.64.png'
    },
    {
        id: '3',
        value: 'GS Facial Spa',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/10/12/01101251/_jcr_content/fullImage.img.160.160.png.64.64.png'
    },
    {
        id: '4',
        value: 'Nu Skin® Facial Spa',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550013/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000'
    },
    {
        id: '5',
        value: 'AP 24® Whitening Fluoride Toothpaste',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990100/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000'
    },
    {
        id: '6',
        value: 'PowerMask + LumiSpa Normal Subscription',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/00/16/01001647/jcr:content/fullImage.img.160.160.png/1611763135883-cache.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000'
    },

    {
        id: '7',
        value: 'Rejuvenating Cream',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990168/_jcr_content/fullImage.img.160.160.png.64.64.png'
    },
    {
        id: '8',
        value: 'Epoch® Firewalker® Foot Cream',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550014/_jcr_content/fullImage.img.160.160.png.64.64.png'
    },
    {
        id: '9',
        value: 'Tri-Phasic White® Night Cream',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/10/12/01101251/_jcr_content/fullImage.img.160.160.png.64.64.png'
    },
    {
        id: '10',
        value: 'ThirstFix Hydrating Gel Cream (Sample Size)',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/55/00/01550013/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000'
    },
    {
        id: '11',
        value: 'Epoch® Baby Hair',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/86/99/01/86990100/_jcr_content/fullImage.img.160.160.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000'
    },
    {
        id: '12',
        value: '180° Face Wash',
        group: 'Popular Searches',
        image: 'https://www.nuskin.com/content/products/01/00/16/01001647/jcr:content/fullImage.img.160.160.png/1611763135883-cache.png.64.64.png',
        icon: 'cart',
        groupBgColor: '#000'
    }
];
